@@ -44,6 +44,9 @@ class VersionArgument(click.Argument):
 
     def process_value(self, ctx, value):
         try:
+            # handle sentinels in click ≥ 8.3.0
+            if hasattr(value, "name") and value.name == "UNSET":
+                value = None
             tool_metadata_file_path = None
             if "tool_metadata_file_path" in ctx.params:
                 tool_metadata_file_path = ctx.params["tool_metadata_file_path"]
@@ -100,7 +103,8 @@ def opt_pdk_root(function: Callable):
         "--pdk",
         cls=PDKOption,
         required=True,
-        help="A valid PDK family or variant (the latter of which is resolved to a family).",
+        envvar=["PDK_FAMILY", "PDK"],
+        help="A valid PDK family or variant (the latter of which is resolved to a family). If the environment PDK_FAMILY or PDK are set, they are used as secondary sources for this value.",
     )(function)
     function = opt(
         "--pdk-root",
